window.Gleam.initSearch([{"doc":"temporary","title":"temporary","content":"# temporary\n\n[![Package Version](https://img.shields.io/hexpm/v/temporary)](https://hex.pm/packages/temporary)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/temporary/)\n![Supported targets](https://img.shields.io/badge/supports-all_targets-ffaff3)\n\n🗂️ A package to work with temporary files and directories in Gleam!\n\n## Installation\n\nTo add this package to your Gleam project:\n\n```sh\ngleam add temporary\n```\n\n## Usage\n\nYou can create temporary files and directories using the `temporary.create`\nfunction. And you don&#39;t have to worry about cleaning up, any temporary file will\nbe deleted automatically once the function is over!\n\n```gleam\nimport temporary\nimport simplifile\n\npub fn main() {\n  use file &lt;- temporary.create(temporary.file())\n  let assert Ok(_) = simplifile.write(&quot;Hello, world!&quot;, to: file)\n}\n```\n\nYou can find the full documentation on [Hex!](https://hex.pm/packages/temporary)\n","url":"index.html"},{"doc":"temporary","title":"TempFile","content":"pub opaque type TempFile\n\n\nSynonyms:\ntemporary.TempFile\ntemporary TempFile","url":"temporary.html#TempFile"},{"doc":"temporary","title":"create","content":"pub fn create(\n  temp_file: TempFile,\n  run fun: fn(String) -&gt; a,\n) -&gt; Result(a, FileError)\n Creates a temporary file and runs the given function passing it the full\n path to that file.\n\n Returns the result of the function wrapped in `Ok`, or `Error` wrapping a\n [`simplifile.FileError`](https://hexdocs.pm/simplifile/simplifile.html#FileError)\n if the file could not be created.\n\n In any case, any temporary file will automatically be deleted!\n\n ## Examples\n\n To create a default temporary file:\n\n \n pub fn main() {\n   use file &lt;- temporary.create(temporary.file())\n   let assert Ok(_) = simplifile.write(&quot;Hello!&quot;, to: file)\n }\n \n\n You can even create more complex temporary directories with temporary files\n inside:\n\n \n pub fn main() {\n   use dir &lt;- temporary.create(temporary.directory())\n   let file = temporary.file() |&gt; temporary.in_directory(dir)\n   use file &lt;- temporary.create(file)\n   //  ^^^^ `file` will be under the `dir` temporary directory!\n\n   let assert Ok(_) = simplifile.write(&quot;Hello!&quot;, to: file)\n }\n \n\nSynonyms:\ntemporary.create\ntemporary create","url":"temporary.html#create"},{"doc":"temporary","title":"directory","content":"pub fn directory() -&gt; TempFile\n The description of a new default temporary directory.\n\n It can be customised using the `set_prefix`, `set_suffix` or `in_directory`\n functions.\n\nSynonyms:\ntemporary.directory\ntemporary directory","url":"temporary.html#directory"},{"doc":"temporary","title":"file","content":"pub fn file() -&gt; TempFile\n The description of a new default temporary file.\n\n It can be customised using the `set_prefix`, `set_suffix` or `in_directory`\n functions.\n\nSynonyms:\ntemporary.file\ntemporary file","url":"temporary.html#file"},{"doc":"temporary","title":"in_directory","content":"pub fn in_directory(\n  temp_file: TempFile,\n  directory: String,\n) -&gt; TempFile\n Set the directory the random file is going to be placed into.\n If this value is not set, the system&#39;s default temp directory is picked,\n searching in the following order:\n\n 1. The value of the `TMPDIR` environment variable, if it is set\n 2. The value of the `TEMP` environment variable, if it is set\n 3. The value of the `TMP` environment variable, if it is set\n 4. `C:\\TMP` on Windows or `/tmp` on Unix-like operating systems\n\n ## Examples\n\n If you don&#39;t want to put the temporary file under the system&#39;s default temp\n directory you can set your own:\n\n \n temporary.file()\n |&gt; temporary.in_directory(&quot;/Users/me/custom_temp_dir&quot;)\n \n\nSynonyms:\ntemporary.in_directory\ntemporary in_directory","url":"temporary.html#in_directory"},{"doc":"temporary","title":"with_prefix","content":"pub fn with_prefix(\n  temp_file: TempFile,\n  name_prefix: String,\n) -&gt; TempFile\n Set a fixed prefix that is going to be added to the temporary file&#39;s name.\n\n ## Examples\n\n \n temporary.file()\n |&gt; temporary.with_prefix(&quot;wibble&quot;)\n |&gt; temporary.create(fn(file) {\n   // The temporary file will have a random\n   // name that starts with `wibble`.\n })\n \n\nSynonyms:\ntemporary.with_prefix\ntemporary with_prefix","url":"temporary.html#with_prefix"},{"doc":"temporary","title":"with_suffix","content":"pub fn with_suffix(\n  temp_file: TempFile,\n  name_suffix: String,\n) -&gt; TempFile\n Set a fixed suffix that is going to be added to the temporary file&#39;s name.\n\n ## Examples\n\n \n temporary.file()\n |&gt; temporary.with_suffix(&quot;wibble&quot;)\n |&gt; temporary.create(fn(file) {\n   // The temporary file will have a random name\n   // that ends with `wibble`.\n })\n\n \n\nSynonyms:\ntemporary.with_suffix\ntemporary with_suffix","url":"temporary.html#with_suffix"},{"doc":"temporary","title":"temporary","content":"","url":"temporary.html"}]);